
This is a plan for next incompatible changes - they are primarily renames.

*   TODO: Introduce `@/data/` dir. And make importable yaml (e.g. from `@/data/`) for server config.

*   TODO: TODO_66_66_75_78.split_arg_and_prop_concepts: Rename: `arg_type` to `prop_name`

*   TODO: Rename: `relay_server` package to `argrelay_server` (to search `argrelay_server` and find relevant stuff).
*   TODO: Rename: `relay_client` package to `argrelay_client` (to search `argrelay_client` and find relevant stuff).

TODO:
*   Rename all enum items to underscore (e.g. `ServerAction.ProposeArgValues` -> `ServerAction.propse_args_values`).
*   TODO: Consider renaming URL, for example (`_` to `-`, shorten, rethink):
    *   propose_arg_values -> propose-options
    *   describe_line_args -> enum-options
    *   relay_line_args -> invoke-with-options
*   TODO: Rename rest API:
    *   `describe_line_args` -> `query_enum_items` (to match func_id)
    *   `propose_arg_values` -> `complete_line`
    *   `relay_line_args` -> `invoke_line`

*   TODO: Rename `ConfiguratorDefault` to `GuiConfigurator`.
*   TODO: Move all GUI config into ConfiguratorDefault (including banner).
*   TODO: Move `gui_banner_config` under `ConfiguratorDefault`

*   TODO: TODO_19_67_22_89: remove `ignored_func_ids_list` - load as `FuncState.fs_unplugged`.

*   TODO: Shorten name `EnvelopeContainer.filled_types_to_values_hidden_by_defaults` to `default_override`-s.

*   TODO: Move GUI header and footer to the configurator.

*   TODO: Remove `relay_demo` linked command after creating new screencast with `lay` linked command. 
